-- -----------------------------------------------------
-- Table `sphere`.`stat_dl_log`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `stat_dl_log` ;

CREATE TABLE IF NOT EXISTS `stat_dl_log` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `file_id` INT UNSIGNED NULL,
  `frame_type_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `date` TIMESTAMP NOT NULL,
  `server` ENUM('sphere-dc', 'cobrex-dc', 'sphere-dc-dev', 'cobrex-dc-dev') NOT NULL,
  `url` VARCHAR(255) NOT NULL,
  `ip` VARCHAR(40) NULL,
  `params` VARCHAR(255) NULL,
  `size` BIGINT NULL,
  `source` ENUM('client', 'direct', 'api', 'script', 'tdb', 'js9', 'vo') NULL,
  `code` INT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_stat_dl_realtime_file1_idx` (`file_id` ASC),
  INDEX `fk_stat_dl_realtime_user1_idx` (`user_id` ASC),
  INDEX `fk_stat_dl_log_frame_type1_idx` (`frame_type_id` ASC),
  CONSTRAINT `fk_stat_dl_log_file1`
    FOREIGN KEY (`file_id`)
    REFERENCES `file` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_log_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_log_frame_type1`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `frame_type` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
;


-- -----------------------------------------------------
-- Table `sphere`.`geoip_country`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `geoip_country` ;

CREATE TABLE IF NOT EXISTS `geoip_country` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `iso` VARCHAR(6) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `geoip_country_name1_uq` (`name` ASC),
  UNIQUE INDEX `geoip_country_iso1_uq` (`iso` ASC))
;


-- -----------------------------------------------------
-- Table `sphere`.`geoip_city`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `geoip_city` ;

CREATE TABLE IF NOT EXISTS `geoip_city` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `latitude` DOUBLE NULL,
  `longitude` DOUBLE NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `geoip_city_name1_uq` (`name` ASC))
;


-- -----------------------------------------------------
-- Table `sphere`.`stat_dl`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `stat_dl` ;

CREATE TABLE IF NOT EXISTS `stat_dl` (
  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
  `frame_type_id` INT UNSIGNED NULL,
  `user_id` INT UNSIGNED NULL,
  `date` DATE NOT NULL,
  `server` ENUM('sphere-dc', 'cobrex-dc', 'sphere-dc-dev', 'cobrex-dc-dev') NOT NULL,
  `count` INT NOT NULL DEFAULT 0,
  `size` BIGINT NOT NULL DEFAULT 0,
  `source` ENUM('client', 'direct', 'api', 'script', 'tdb', 'js9', 'vo') NULL,
  `geoip_country_id` INT UNSIGNED NULL,
  `geoip_city_id` INT UNSIGNED NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_stat_dl_realtime_user1_idx` (`user_id` ASC),
  INDEX `fk_stat_dl_log_frame_type1_idx` (`frame_type_id` ASC),
  INDEX `fk_stat_dl_geoip_country1_idx` (`geoip_country_id` ASC),
  INDEX `fk_stat_dl_geoip_city1_idx` (`geoip_city_id` ASC),
  CONSTRAINT `fk_stat_dl_user10`
    FOREIGN KEY (`user_id`)
    REFERENCES `user` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_frame_type10`
    FOREIGN KEY (`frame_type_id`)
    REFERENCES `frame_type` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_geoip_country1`
    FOREIGN KEY (`geoip_country_id`)
    REFERENCES `geoip_country` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_stat_dl_geoip_city1`
    FOREIGN KEY (`geoip_city_id`)
    REFERENCES `geoip_city` (`id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
;