drop table if exists temp_ac_obs;

create temporary table temp_ac_obs
select id, container_id, coord_RA, coord_DEC, obs_id,dpr_type,object,target, star_spectral_type, count(*)
from attribute_cache
where 
    id > 0
    and coord_RA is not null
    and coord_DEC is not null
    and not (coord_RA = 0
    and coord_DEC = 0)
    and obs_id is not null
    and obs_id > 0
group by obs_id,target,dpr_type
order by obs_id;

drop table if exists temp_ac_obs_counts;

create temporary table temp_ac_obs_counts
select id, container_id, coord_RA, coord_DEC, obs_id,dpr_type,object,target, star_spectral_type, count(*) as count from temp_ac_obs 
group by obs_id
order by count;

drop table if exists temp_ac_obs_join;
create temporary table temp_ac_obs_join
select o.id, o.container_id, o.coord_RA, o.coord_DEC, o.obs_id,o.dpr_type,o.object,o.target, o.star_spectral_type from temp_ac_obs_counts c
join temp_ac_obs o on o.obs_id=c.obs_id
where c.count > 1;

select o.id, o.container_id, o.coord_RA, o.coord_DEC, o.obs_id,o.dpr_type,o.object,o.target, o.star_spectral_type from temp_ac_obs_join o
order by o.obs_id;

drop table if exists temp_ac_obs_join_group;
create temporary table temp_ac_obs_join_group
select id, container_id, coord_RA, coord_DEC,obs_id, dpr_type, object, target,  star_spectral_type from temp_ac_obs_join
where dpr_type != 'SKY' and dpr_type != 'DARK' and dpr_type not like '%FLAT%'
group by obs_id,target;

-- to be harmonized attribute caches where same obs_id has more than one target
select o.id, o.container_id, o.coord_RA, o.coord_DEC, o.obs_id,o.dpr_type,o.object,o.target, o.star_spectral_type from temp_ac_obs_join_group o
;

-- to be harmonized attribute caches where same obs_id has more than one target
drop table if exists temp_to_be_harmonized_ac;
create temporary table temp_to_be_harmonized_ac
select obs_id, count(*) as count from temp_ac_obs_join_group
group by obs_id;

drop table if exists temp_ac_harmonization_propal;
create temporary table temp_ac_harmonization_propal
select h.obs_id, g.container_id, h.count as target_count, g.target as proposed_harmonized_target from temp_to_be_harmonized_ac h
left join temp_ac_obs_join_group g
on h.obs_id = g.obs_id and g.object is not null and g.object != '' and g.object != 'OBJECT' and g.dpr_type is not null and g.dpr_type != ''
where h.count > 1
order by h.count desc, h.obs_id asc;

-- unresolvable attribute cache targets
drop table if exists temp_ac_harmonization_issue;
create temporary table temp_ac_harmonization_issue
select obs_id, container_id, target_count, proposed_harmonized_target, count(*) as proposed_target_count from temp_ac_harmonization_propal
group by obs_id
;

-- proposition of attribute cache target harmonization
select obs_id, container_id, target_count, proposed_harmonized_target from temp_ac_harmonization_issue
where proposed_target_count = 1
;
-- remaining unresolvable attribute cache targets where more than one proposed harmonized target
select p.obs_id, i.container_id, p.target_count, p.proposed_harmonized_target, i.proposed_target_count from temp_ac_harmonization_issue i
left join temp_ac_harmonization_propal p 
on p.obs_id = i.obs_id
where proposed_target_count > 1
;

-- star hopping among remaining unresolvable attribute cache targets
select p.obs_id, i.container_id, p.target_count, p.proposed_harmonized_target, i.proposed_target_count from temp_ac_harmonization_issue i
left join temp_ac_harmonization_propal p
on p.obs_id = i.obs_id
where proposed_target_count > 1 and i.container_id is not null and i.container_id <> '-999';

-- not star hopping among remaining unresolvable attribute cache targets
select p.obs_id, i.container_id, p.target_count, p.proposed_harmonized_target, i.proposed_target_count from temp_ac_harmonization_issue i
left join temp_ac_harmonization_propal p
on p.obs_id = i.obs_id
where proposed_target_count > 1 and (i.container_id = '-999' or i.container_id is null)
group by p.obs_id;

